# Anjani

[![forthebadge made-with-python](http://ForTheBadge.com/images/badges/made-with-python.svg)](https://www.python.org/)

[![DeepSource](https://deepsource.io/gh/userbotindo/Anjani.svg/?label=active+issues)](https://deepsource.io/gh/userbotindo/Anjani/?ref=repository-badge)
[![PyPI](https://img.shields.io/pypi/v/anjani.svg)](https://pypi.org/project/anjani/)

Can be found on Telegram as [Anjani](https://t.me/dAnjani_bot).

Anjani is a modern, easy-to-develop, fully async Telegram group managing bot for Telegram.

## Requirements

-   Python 3.9 or higher.
-   [Telegram API key](https://docs.pyrogram.org/intro/setup#api-keys).
-   [Telegram Bot Token](https://t.me/botfather)
-   [MongoDB Database](https://cloud.mongodb.com/).

## Features

-   Easy to develop with object oriented models.
-   Fully asynchronous with async / await.
-   Type-hinted method making it easy to create plugins.
-   Localization support.
-   Class based plugin system.

## [Documentation](https://userbotindo.com/anjani/docs/home)

## [Installing](https://userbotindo.com/anjani/docs/install)

## Plugin

If you want to make your custom plugins, refer to [Anjani's Plugins Guide](https://userbotindo.com/anjani/docs/plugin/creating-your-own-plugin).

## Credits

-   [Marie](https://github.com/PaulSonOfLars/tgbot)
-   [Pyrobud](https://github.com/kdrag0n/pyrobud)
-   [All Contributors 👥](https://github.com/userbotindo/Anjani/graphs/contributors)
